pub struct TestAccount {
user: InitUserCryptoRequest,
org: Option<InitOrgCryptoRequest>,
}Expand description
Test Account
Many of the SDK tests are based on encrypted data provided by the other Bitwarden clients. In order to provide a consistent method of retrieving the data we provide a test account with user keys.
Disclaimer: The server typically encrypts and protects certain fields. In order to allow accounts to be used on other servers this protection was explicitly removed from these data dumps.
Fields
user: InitUserCryptoRequestorg: Option<InitOrgCryptoRequest>Auto Trait Implementations
impl Freeze for TestAccount
impl RefUnwindSafe for TestAccount
impl Send for TestAccount
impl Sync for TestAccount
impl Unpin for TestAccount
impl UnsafeUnpin for TestAccount
impl UnwindSafe for TestAccount